#!/usr/bin/env node

var program = require('commander');
var mkdirp = require('mkdirp');
var fs = require('fs');
var ncp = require('ncp').ncp;
var pkg = require('./package.json');

const version = pkg.version
const currentPath = process.cwd();

program.name('linkbox')
  .version(pkg.version, '    --version')
	.option('-n, --project_name <project_name>', 'The name of project')
  .action(function(arg) {
    	createProject(arg, program.project_name);
  }).parse(process.argv);


async function createProject(type, name) {
	let makeDirMsg = await makeDir(name);
	console.log(makeDirMsg);
	let copyTemplateMsg = await copyTemplate(name);
	console.log(copyTemplateMsg);
	let makePackageMsg = await makePackage(name);
	console.log(makePackageMsg);
}

function copyTemplate(name) {
	return new Promise((resolve, reject) => {
		ncp(__dirname + '/template', currentPath + '/' + name, function (err) {
		 	if (err) return reject(err);
		 	return resolve("Template copied successfully")
		});
	});
}

function makeDir(name) {
	return new Promise((resolve, reject) => {
		mkdirp(currentPath + '/' + name, function (err) {
    	if (err) console.error(err)
    	return resolve('Project created successfully')
		});
	});
}

function makePackage(name) {
	let package = {
	  "name": name,
	  "version": "1.0.0",
	  "description": "",
	  "main": "index.js",
	  "scripts": {
	    "start": "node dist/App.js"
	  },
	  "author": "Linkbox",
	  "license": "MIT",
	  "dependencies": {
	    "@maildots/sdk": "^1.2.2",
	    "bluebird": "^3.5.0",
	    "body-parser": "^1.18.0",
	    "crypto": "^1.0.1",
	    "dotenv": "^4.0.0",
	    "express": "^4.15.4",
	    "mongodb": "^2.2.31",
	    "path": "^0.12.7"
	  },
	  "devDependencies": {
			"@types/node": "^8.0.28",
			"@types/bluebird": "^3.5.18",
			"@types/dotenv": "^4.0.2",
			"@types/mongodb": "^2.2.16",
			"@types/request": "^2.0.8"
	  },
	  "engines": {
	    "node": "8.1.4"
	  }
	}

	return new Promise((resolve, reject) => {
		fs.writeFile(currentPath + '/' + name + '/package.json', JSON.stringify(package,null,2), function(err) {
	    if(err) return reject(err);
	    return resolve("Package created successsfully");
		}); 
	});
}